@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 """ icdiff.py
 
@@ -23,7 +23,7 @@ import filecmp
 import unicodedata
 import codecs
 
-__version__ = "1.9.5"
+__version__ = "2.0.3"
 
 color_codes = {
     "black":   '\033[0;30m',
@@ -87,6 +87,7 @@ class ConsoleDiff(object):
                  line_numbers=False,
                  show_all_spaces=False,
                  highlight=False,
+                 truncate=False,
                  strip_trailing_cr=False):
         """ConsoleDiff instance initializer
 
@@ -105,6 +106,7 @@ class ConsoleDiff(object):
         self.show_all_spaces = show_all_spaces
         self.highlight = highlight
         self.strip_trailing_cr = strip_trailing_cr
+        self.truncate = truncate
 
         if wrapcolumn is None:
             if not line_numbers:
@@ -171,50 +173,58 @@ class ConsoleDiff(object):
         text line list.  This function is used recursively to handle
         the second part of the split line to further split it.
         """
-        # if blank line or context separator, just add it to the output list
-        if not line_num:
-            data_list.append((line_num, text))
-            return
 
-        # if line text doesn't need wrapping, just add it to the output list
-        if ((self._display_len(text) - (text.count('\0') * 3) <=
-             self._wrapcolumn)):
-            data_list.append((line_num, text))
-            return
+        while True:
+            # if blank line or context separator, just add it to the output
+            # list
+            if not line_num:
+                data_list.append((line_num, text))
+                return
 
-        # scan text looking for the wrap point, keeping track if the wrap
-        # point is inside markers
-        i = 0
-        n = 0
-        mark = ''
-        while n < self._wrapcolumn and i < len(text):
-            if text[i] == '\0':
-                i += 1
-                mark = text[i]
-                i += 1
-            elif text[i] == '\1':
-                i += 1
-                mark = ''
-            else:
-                n += self._display_len(text[i])
-                i += 1
+            # if line text doesn't need wrapping, just add it to the output
+            # list
+            if ((self._display_len(text) - (text.count('\0') * 3) <=
+                 self._wrapcolumn)):
+                data_list.append((line_num, text))
+                return
 
-        # wrap point is inside text, break it up into separate lines
-        line1 = text[:i]
-        line2 = text[i:]
+            # scan text looking for the wrap point, keeping track if the wrap
+            # point is inside markers
+            i = 0
+            n = 0
+            mark = ''
+            while n < self._wrapcolumn and i < len(text):
+                if text[i] == '\0':
+                    i += 1
+                    mark = text[i]
+                    i += 1
+                elif text[i] == '\1':
+                    i += 1
+                    mark = ''
+                else:
+                    n += self._display_len(text[i])
+                    i += 1
 
-        # if wrap point is inside markers, place end marker at end of first
-        # line and start marker at beginning of second line because each
-        # line will have its own table tag markup around it.
-        if mark:
-            line1 = line1 + '\1'
-            line2 = '\0' + mark + line2
+            # wrap point is inside text, break it up into separate lines
+            line1 = text[:i]
+            line2 = text[i:]
 
-        # tack on first line onto the output list
-        data_list.append((line_num, line1))
+            # if wrap point is inside markers, place end marker at end of first
+            # line and start marker at beginning of second line because each
+            # line will have its own table tag markup around it.
+            if mark:
+                line1 = line1 + '\1'
+                line2 = '\0' + mark + line2
 
-        # use this routine again to wrap the remaining text
-        self._split_line(data_list, '>', line2)
+            # tack on first line onto the output list
+            data_list.append((line_num, line1))
+
+            # use this routine again to wrap the remaining text
+            # unless truncate is set
+            if self.truncate:
+                return
+            line_num = '>'
+            text = line2
 
     def _line_wrapper(self, diffs):
         """Returns iterator that splits (wraps) mdiff text lines"""
@@ -510,6 +520,9 @@ def create_option_parser():
     parser.add_option("-r", "--recursive", default=False,
                       action="store_true",
                       help="recursively compare subdirectories")
+    parser.add_option("-s", "--report-identical-files", default=False,
+                      action="store_true",
+                      help="report when two files are the same")
     parser.add_option("--show-all-spaces", default=False,
                       action="store_true",
                       help="color all non-matching whitespace including "
@@ -517,6 +530,9 @@ def create_option_parser():
                       "changes.  Slow, ugly, displays all changes")
     parser.add_option("--tabsize", default=8,
                       help="tab stop spacing")
+    parser.add_option("-t", "--truncate", default=False,
+                      action="store_true",
+                      help="truncate long lines instead of wrapping them")
     parser.add_option("-u", "--patch", default=True,
                       action="store_true",
                       help="generate patch. This is always true, "
@@ -594,7 +610,22 @@ def start():
     validate_has_two_arguments(parser, args)
     if not options.cols:
         set_cols_option(options)
-    diff(options, *args)
+    try:
+        diff(options, *args)
+    except KeyboardInterrupt:
+        pass
+    except IOError as e:
+        if e.errno == errno.EPIPE:
+            pass
+        else:
+            raise
+
+    # Close stderr to prevent printing errors when icdiff is piped to
+    # something that closes before icdiff is done writing
+    #
+    # See: https://stackoverflow.com/questions/26692284/...
+    #      ...how-to-prevent-brokenpipeerror-when-doing-a-flush-in-python
+    sys.stderr.close()
 
 
 def codec_print(s, options):
@@ -618,6 +649,8 @@ def diff(options, a, b):
         try:
             if not filecmp.cmp(a, b, shallow=False):
                 diff_files(options, a, b)
+            elif options.report_identical_files:
+                print("Files %s and %s are identical." % (a, b))
         except OSError as e:
             if e.errno == errno.ENOENT:
                 print_meta("error: file '%s' was not found" % e.filename)
@@ -745,6 +778,7 @@ def diff_files(options, a, b):
                      highlight=options.highlight,
                      line_numbers=options.line_numbers,
                      tabsize=int(options.tabsize),
+                     truncate=options.truncate,
                      strip_trailing_cr=options.strip_trailing_cr)
     for line in cd.make_table(
             lines_a, lines_b, headers[0], headers[1],
@@ -755,18 +789,4 @@ def diff_files(options, a, b):
 
 
 if __name__ == "__main__":
-    try:
-        start()
-    except KeyboardInterrupt:
-        pass
-    except IOError as e:
-        if e.errno == errno.EPIPE:
-            pass
-        else:
-            raise
-    # Close stderr to prevent printing errors when icdiff is piped to
-    # something that closes before icdiff is done writing
-    #
-    # See: https://stackoverflow.com/questions/26692284/
-    #              how-to-prevent-brokenpipeerror-when-doing-a-flush-in-python
-    sys.stderr.close()
+    start()
